package com.aucma.report.service;

import java.util.List;
import com.aucma.report.domain.ReportPointDnb;

/**
 * 电整点耗量报表Service接口
 * 
 * @author ruoyi
 * @date 2023-10-09
 */
public interface IReportPointDnbService 
{
    /**
     * 查询电整点耗量报表
     * 
     * @param objId 电整点耗量报表主键
     * @return 电整点耗量报表
     */
    public ReportPointDnb selectReportPointDnbByObjId(Long objId);

    /**
     * 查询电整点耗量报表列表
     * 
     * @param reportPointDnb 电整点耗量报表
     * @return 电整点耗量报表集合
     */
    public List<ReportPointDnb> selectReportPointDnbList(ReportPointDnb reportPointDnb);

    /**
     * 新增电整点耗量报表
     * 
     * @param reportPointDnb 电整点耗量报表
     * @return 结果
     */
    public int insertReportPointDnb(ReportPointDnb reportPointDnb);

    /**
     * 修改电整点耗量报表
     * 
     * @param reportPointDnb 电整点耗量报表
     * @return 结果
     */
    public int updateReportPointDnb(ReportPointDnb reportPointDnb);

    /**
     * 批量删除电整点耗量报表
     * 
     * @param objIds 需要删除的电整点耗量报表主键集合
     * @return 结果
     */
    public int deleteReportPointDnbByObjIds(Long[] objIds);

    /**
     * 删除电整点耗量报表信息
     * 
     * @param objId 电整点耗量报表主键
     * @return 结果
     */
    public int deleteReportPointDnbByObjId(Long objId);
}
