package com.aucma.report.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.aucma.common.utils.DateUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.aucma.common.annotation.Log;
import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.enums.BusinessType;
import com.aucma.report.domain.ReportPointDnb;
import com.aucma.report.service.IReportPointDnbService;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.common.core.page.TableDataInfo;

/**
 * 电整点耗量报表Controller
 *
 * @author ruoyi
 * @date 2023-10-09
 */
@RestController
@RequestMapping("/report/pointDnb" )
public class ReportPointDnbController extends BaseController {
    @Autowired
    private IReportPointDnbService reportPointDnbService;

    /**
     * 查询电整点耗量报表列表
     */
    @PreAuthorize("@ss.hasPermi('report:pointDnb:list')" )
    @GetMapping("/list" )
    public TableDataInfo list(ReportPointDnb reportPointDnb) {
        startPage();
        List<ReportPointDnb> list = reportPointDnbService.selectReportPointDnbList(reportPointDnb);
        return getDataTable(list);
    }


    /**
     * 导出电整点耗量报表列表
     */
    @PreAuthorize("@ss.hasPermi('report:pointDnb:export')" )
    @Log(title = "电整点耗量报表" , businessType = BusinessType.EXPORT)
    @PostMapping("/export" )
    public void export(HttpServletResponse response, ReportPointDnb reportPointDnb) {
        List<ReportPointDnb> list = reportPointDnbService.selectReportPointDnbList(reportPointDnb);
        ExcelUtil<ReportPointDnb> util = new ExcelUtil<ReportPointDnb>(ReportPointDnb. class);
        util.exportExcel(response, list, "电整点耗量报表数据" );
    }

    /**
     * 获取电整点耗量报表详细信息
     */
    @PreAuthorize("@ss.hasPermi('report:pointDnb:query')" )
    @GetMapping(value = "/{objId}" )
    public AjaxResult getInfo(@PathVariable("objId" ) Long objId) {
        return success(reportPointDnbService.selectReportPointDnbByObjId(objId));
    }

    /**
     * 新增电整点耗量报表
     */
    @PreAuthorize("@ss.hasPermi('report:pointDnb:add')" )
    @Log(title = "电整点耗量报表" , businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ReportPointDnb reportPointDnb) {
        reportPointDnb.setCreatedBy(getUsername());
        reportPointDnb.setCreatedTime(DateUtils.getNowDate());
        return toAjax(reportPointDnbService.insertReportPointDnb(reportPointDnb));
    }

    /**
     * 修改电整点耗量报表
     */
    @PreAuthorize("@ss.hasPermi('report:pointDnb:edit')" )
    @Log(title = "电整点耗量报表" , businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ReportPointDnb reportPointDnb) {
        reportPointDnb.setUpdatedBy(getUsername());
        reportPointDnb.setUpdatedTime(DateUtils.getNowDate());
        return toAjax(reportPointDnbService.updateReportPointDnb(reportPointDnb));
    }

    /**
     * 删除电整点耗量报表
     */
    @PreAuthorize("@ss.hasPermi('report:pointDnb:remove')" )
    @Log(title = "电整点耗量报表" , businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}" )
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(reportPointDnbService.deleteReportPointDnbByObjIds(objIds));
    }
}
